# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/solution.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/atlas/solution.proto\x12\x0c\x65olymp.atlas\x1a!eolymp/annotations/resource.proto\"\x9a\x03\n\x08Solution\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x11\n\tauthor_id\x18\x03 \x01(\t\x12\x11\n\tpublished\x18\x05 \x01(\x08\x12<\n\x11moderation_status\x18\x06 \x01(\x0e\x32!.eolymp.atlas.Solution.Moderation\x12\x1a\n\x12moderation_comment\x18\x07 \x01(\t\x12\x0e\n\x06locale\x18\n \x01(\t\x12-\n\x06\x66ormat\x18\x0b \x01(\x0e\x32\x1d.eolymp.atlas.Solution.Format\x12\x0f\n\x07\x63ontent\x18\x0c \x01(\t\"?\n\nModeration\x12\t\n\x05\x44RAFT\x10\x00\x12\n\n\x06REVIEW\x10\x01\x12\x0c\n\x08\x41PPROVED\x10\x02\x12\x0c\n\x08REJECTED\x10\x03\"3\n\x06\x46ormat\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03TEX\x10\x01\x12\x0c\n\x08MARKDOWN\x10\x02\x12\x08\n\x04HTML\x10\x03:(\xb2\xe3\n$\xba\xe3\n\x08solution\xc2\xe3\n\x14\x65olymp.atlas.ProblemB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.solution_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _SOLUTION._options = None
  _SOLUTION._serialized_options = b'\262\343\n$\272\343\n\010solution\302\343\n\024eolymp.atlas.Problem'
  _SOLUTION._serialized_start=81
  _SOLUTION._serialized_end=491
  _SOLUTION_MODERATION._serialized_start=333
  _SOLUTION_MODERATION._serialized_end=396
  _SOLUTION_FORMAT._serialized_start=398
  _SOLUTION_FORMAT._serialized_end=449
# @@protoc_insertion_point(module_scope)
