# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/interactor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/executor/interactor.proto\x12\x0f\x65olymp.executor\"\xd4\x01\n\nInteractor\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .eolymp.executor.Interactor.Type\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12/\n\x05\x66iles\x18\n \x03(\x0b\x32 .eolymp.executor.Interactor.File\x1a(\n\x04\x46ile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nsource_ern\x18\x02 \x01(\t\"\x1d\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PROGRAM\x10\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.interactor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _INTERACTOR._serialized_start=54
  _INTERACTOR._serialized_end=266
  _INTERACTOR_FILE._serialized_start=195
  _INTERACTOR_FILE._serialized_end=235
  _INTERACTOR_TYPE._serialized_start=237
  _INTERACTOR_TYPE._serialized_end=266
# @@protoc_insertion_point(module_scope)
