# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/entitlement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/cognito/entitlement.proto\x12\x0e\x65olymp.cognito*z\n\x0b\x45ntitlement\x12\x17\n\x13VIEW_PUBLIC_PROFILE\x10\x00\x12\x18\n\x14VIEW_BLOCKED_PROFILE\x10\x01\x12\x15\n\x11VIEW_PRIVATE_DATA\x10\x02\x12\x10\n\x0cMANAGE_ROLES\x10\x03\x12\x0f\n\x0b\x42LOCK_USERS\x10\x04\x42\x31Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.entitlement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _ENTITLEMENT._serialized_start=52
  _ENTITLEMENT._serialized_end=174
# @@protoc_insertion_point(module_scope)
