# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/keeper/blob.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/keeper/blob.proto\x12\reolymp.keeper\x1a!eolymp/annotations/resource.proto\"_\n\x04\x42lob\x12\x0b\n\x03\x65rn\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04hash\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c:\x13\xb2\xe3\n\x0f\xba\xe3\n\x04\x62lob\xca\xe3\n\x03keyB/Z-github.com/eolymp/go-sdk/eolymp/keeper;keeperb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.keeper.blob_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/keeper;keeper'
  _BLOB._options = None
  _BLOB._serialized_options = b'\262\343\n\017\272\343\n\004blob\312\343\n\003key'
  _BLOB._serialized_start=78
  _BLOB._serialized_end=173
# @@protoc_insertion_point(module_scope)
