# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/acl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65olymp/judge/acl.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\"\x7f\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\x04role\x18\x02 \x01(\x0e\x32\x1d.eolymp.judge.Permission.Role\x12\x0f\n\x07user_id\x18\x03 \x01(\t\"\'\n\x04Role\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\n\n\x06VIEWER\x10\x02\"5\n\x14GrantPermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"\x17\n\x15GrantPermissionOutput\"(\n\x15RevokePermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\x18\n\x16RevokePermissionOutput\"*\n\x17\x44\x65scribePermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"H\n\x18\x44\x65scribePermissionOutput\x12,\n\npermission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Permission\"\x9a\x02\n\x14ListPermissionsInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListPermissionsInput.Filter\x1a\x95\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04role\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"O\n\x15ListPermissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Permission2\xb6\x04\n\x03\x41\x63l\x12\x89\x01\n\x0fGrantPermission\x12\".eolymp.judge.GrantPermissionInput\x1a#.eolymp.judge.GrantPermissionOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18\x1a\x16/permissions/{user_id}\x12\x8c\x01\n\x10RevokePermission\x12#.eolymp.judge.RevokePermissionInput\x1a$.eolymp.judge.RevokePermissionOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18*\x16/permissions/{user_id}\x12\x92\x01\n\x12\x44\x65scribePermission\x12%.eolymp.judge.DescribePermissionInput\x1a&.eolymp.judge.DescribePermissionOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18\x12\x16/permissions/{user_id}\x12\x7f\n\x0fListPermissions\x12\".eolymp.judge.ListPermissionsInput\x1a#.eolymp.judge.ListPermissionsOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/permissionsB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.acl_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _ACL.methods_by_name['GrantPermission']._options = None
  _ACL.methods_by_name['GrantPermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\030\032\026/permissions/{user_id}'
  _ACL.methods_by_name['RevokePermission']._options = None
  _ACL.methods_by_name['RevokePermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\030*\026/permissions/{user_id}'
  _ACL.methods_by_name['DescribePermission']._options = None
  _ACL.methods_by_name['DescribePermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\030\022\026/permissions/{user_id}'
  _ACL.methods_by_name['ListPermissions']._options = None
  _ACL.methods_by_name['ListPermissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\016\022\014/permissions'
  _PERMISSION._serialized_start=142
  _PERMISSION._serialized_end=269
  _PERMISSION_ROLE._serialized_start=230
  _PERMISSION_ROLE._serialized_end=269
  _GRANTPERMISSIONINPUT._serialized_start=271
  _GRANTPERMISSIONINPUT._serialized_end=324
  _GRANTPERMISSIONOUTPUT._serialized_start=326
  _GRANTPERMISSIONOUTPUT._serialized_end=349
  _REVOKEPERMISSIONINPUT._serialized_start=351
  _REVOKEPERMISSIONINPUT._serialized_end=391
  _REVOKEPERMISSIONOUTPUT._serialized_start=393
  _REVOKEPERMISSIONOUTPUT._serialized_end=417
  _DESCRIBEPERMISSIONINPUT._serialized_start=419
  _DESCRIBEPERMISSIONINPUT._serialized_end=461
  _DESCRIBEPERMISSIONOUTPUT._serialized_start=463
  _DESCRIBEPERMISSIONOUTPUT._serialized_end=535
  _LISTPERMISSIONSINPUT._serialized_start=538
  _LISTPERMISSIONSINPUT._serialized_end=820
  _LISTPERMISSIONSINPUT_FILTER._serialized_start=671
  _LISTPERMISSIONSINPUT_FILTER._serialized_end=820
  _LISTPERMISSIONSOUTPUT._serialized_start=822
  _LISTPERMISSIONSOUTPUT._serialized_end=901
  _ACL._serialized_start=904
  _ACL._serialized_end=1470
# @@protoc_insertion_point(module_scope)
