# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/community.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import idp_pb2 as eolymp_dot_community_dot_idp__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/community/community.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/community/attribute.proto\x1a\x1a\x65olymp/community/idp.proto\x1a\x1d\x65olymp/community/member.proto\x1a!eolymp/wellknown/expression.proto\"N\n\x0eJoinSpaceInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x06values\x18\x14 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"2\n\x0fJoinSpaceOutput\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x11\n\tmember_id\x18\x01 \x01(\t\"E\n\x13RegisterMemberInput\x12.\n\x06values\x18\x01 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"\x16\n\x14RegisterMemberOutput\"\x11\n\x0fLeaveSpaceInput\"\x12\n\x10LeaveSpaceOutput\":\n\x0e\x41\x64\x64MemberInput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"2\n\x0f\x41\x64\x64MemberOutput\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x83\x02\n\x11UpdateMemberInput\x12\x38\n\x05patch\x18\x01 \x03(\x0e\x32).eolymp.community.UpdateMemberInput.Patch\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12(\n\x06member\x18\x03 \x01(\x0b\x32\x18.eolymp.community.Member\"w\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x0e\n\nREGISTERED\x10\x03\x12\t\n\x05GHOST\x10\x04\x12\x16\n\x12OUT_OF_COMPETITION\x10\x05\x12\x0e\n\nIDENTITIES\x10\x06\x12\n\n\x06VALUES\x10\x07\"\x14\n\x12UpdateMemberOutput\"&\n\x11RemoveMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x14\n\x12RemoveMemberOutput\"(\n\x13\x44\x65scribeMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"@\n\x14\x44\x65scribeMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\x17\n\x15IntrospectMemberInput\"B\n\x16IntrospectMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\xf0\x03\n\x10ListMembersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.community.ListMembersInput.Filter\x1a\x81\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\x08\x64isabled\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x39\n\ridentity_name\x18\n \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12=\n\x11identity_nickname\x18\x0b \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12:\n\x0eidentity_email\x18\x0c \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"K\n\x11ListMembersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.community.Member\"`\n\x16\x41\x64\x64MemberIdentityInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x33\n\x08identity\x18\x02 \x01(\x0b\x32!.eolymp.community.Member.Identity\".\n\x17\x41\x64\x64MemberIdentityOutput\x12\x13\n\x0bidentity_id\x18\x01 \x01(\t\"x\n\x19UpdateMemberIdentityInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x13\n\x0bidentity_id\x18\x02 \x01(\t\x12\x33\n\x08identity\x18\x03 \x01(\x0b\x32!.eolymp.community.Member.Identity\"\x1c\n\x1aUpdateMemberIdentityOutput\"C\n\x19RemoveMemberIdentityInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x13\n\x0bidentity_id\x18\x02 \x01(\t\"\x1c\n\x1aRemoveMemberIdentityOutput\"Z\n\x11\x41\x64\x64\x41ttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\"\n\x12\x41\x64\x64\x41ttributeOutput\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\"]\n\x14UpdateAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\x17\n\x15UpdateAttributeOutput\"-\n\x14RemoveAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"\x17\n\x15RemoveAttributeOutput\"/\n\x16\x44\x65scribeAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"I\n\x17\x44\x65scribeAttributeOutput\x12.\n\tattribute\x18\x01 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\xee\x02\n\x13ListAttributesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.community.ListAttributesInput.Filter\x1a\xf9\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03key\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06hidden\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08required\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Q\n\x14ListAttributesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.community.Attribute\"\x1f\n\x1d\x44\x65scribeIdentityProviderInput\"v\n\x1e\x44\x65scribeIdentityProviderOutput\x12\x0f\n\x05local\x18\x01 \x01(\x08H\x00\x12\x37\n\x04oidc\x18\x03 \x01(\x0b\x32\'.eolymp.community.IdentityProvider.OIDCH\x00\x42\n\n\x08provider\"v\n\x1e\x43onfigureIdentityProviderInput\x12\x0f\n\x05local\x18\x01 \x01(\x08H\x00\x12\x37\n\x04oidc\x18\x03 \x01(\x0b\x32\'.eolymp.community.IdentityProvider.OIDCH\x00\x42\n\n\x08provider\"!\n\x1f\x43onfigureIdentityProviderOutput2\xd7\x19\n\tCommunity\x12\x94\x01\n\tJoinSpace\x12 .eolymp.community.JoinSpaceInput\x1a!.eolymp.community.JoinSpaceOutput\"B\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10\"\x0e/members/_self\x12\x97\x01\n\nLeaveSpace\x12!.eolymp.community.LeaveSpaceInput\x1a\".eolymp.community.LeaveSpaceOutput\"B\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10*\x0e/members/_self\x12\xaf\x01\n\x0eRegisterMember\x12%.eolymp.community.RegisterMemberInput\x1a&.eolymp.community.RegisterMemberOutput\"N\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1b\"\x19/members/_self/attributes\x12\x8c\x01\n\x10IntrospectMember\x12\'.eolymp.community.IntrospectMemberInput\x1a(.eolymp.community.IntrospectMemberOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x10\x12\x0e/members/_self\x12\x8f\x01\n\tAddMember\x12 .eolymp.community.AddMemberInput\x1a!.eolymp.community.AddMemberOutput\"=\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\n\"\x08/members\x12\xa4\x01\n\x0cUpdateMember\x12#.eolymp.community.UpdateMemberInput\x1a$.eolymp.community.UpdateMemberOutput\"I\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x16\"\x14/members/{member_id}\x12\xa4\x01\n\x0cRemoveMember\x12#.eolymp.community.RemoveMemberInput\x1a$.eolymp.community.RemoveMemberOutput\"I\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x16*\x14/members/{member_id}\x12\xa9\x01\n\x0e\x44\x65scribeMember\x12%.eolymp.community.DescribeMemberInput\x1a&.eolymp.community.DescribeMemberOutput\"H\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x16\x12\x14/members/{member_id}\x12\x94\x01\n\x0bListMembers\x12\".eolymp.community.ListMembersInput\x1a#.eolymp.community.ListMembersOutput\"<\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\n\x12\x08/members\x12\xbe\x01\n\x11\x41\x64\x64MemberIdentity\x12(.eolymp.community.AddMemberIdentityInput\x1a).eolymp.community.AddMemberIdentityOutput\"T\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02!\"\x1f/members/{member_id}/identities\x12\xd5\x01\n\x14UpdateMemberIdentity\x12+.eolymp.community.UpdateMemberIdentityInput\x1a,.eolymp.community.UpdateMemberIdentityOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02/\x1a-/members/{member_id}/identities/{identity_id}\x12\xd5\x01\n\x14RemoveMemberIdentity\x12+.eolymp.community.RemoveMemberIdentityInput\x1a,.eolymp.community.RemoveMemberIdentityOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02/*-/members/{member_id}/identities/{identity_id}\x12\x9b\x01\n\x0c\x41\x64\x64\x41ttribute\x12#.eolymp.community.AddAttributeInput\x1a$.eolymp.community.AddAttributeOutput\"@\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\r\"\x0b/attributes\x12\xb4\x01\n\x0fUpdateAttribute\x12&.eolymp.community.UpdateAttributeInput\x1a\'.eolymp.community.UpdateAttributeOutput\"P\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d\"\x1b/attributes/{attribute_key}\x12\xb4\x01\n\x0fRemoveAttribute\x12&.eolymp.community.RemoveAttributeInput\x1a\'.eolymp.community.RemoveAttributeOutput\"P\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d*\x1b/attributes/{attribute_key}\x12\xb9\x01\n\x11\x44\x65scribeAttribute\x12(.eolymp.community.DescribeAttributeInput\x1a).eolymp.community.DescribeAttributeOutput\"O\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d\x12\x1b/attributes/{attribute_key}\x12\xa0\x01\n\x0eListAttributes\x12%.eolymp.community.ListAttributesInput\x1a&.eolymp.community.ListAttributesOutput\"?\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\r\x12\x0b/attributes\x12\x9a\x01\n\x18\x44\x65scribeIdentityProvider\x12/.eolymp.community.DescribeIdentityProviderInput\x1a\x30.eolymp.community.DescribeIdentityProviderOutput\"\x1b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x06\x12\x04/idp\x12\xbb\x01\n\x19\x43onfigureIdentityProvider\x12\x30.eolymp.community.ConfigureIdentityProviderInput\x1a\x31.eolymp.community.ConfigureIdentityProviderOutput\"9\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x06\x1a\x04/idpB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.community_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _COMMUNITY.methods_by_name['JoinSpace']._options = None
  _COMMUNITY.methods_by_name['JoinSpace']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\020\"\016/members/_self'
  _COMMUNITY.methods_by_name['LeaveSpace']._options = None
  _COMMUNITY.methods_by_name['LeaveSpace']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\020*\016/members/_self'
  _COMMUNITY.methods_by_name['RegisterMember']._options = None
  _COMMUNITY.methods_by_name['RegisterMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\033\"\031/members/_self/attributes'
  _COMMUNITY.methods_by_name['IntrospectMember']._options = None
  _COMMUNITY.methods_by_name['IntrospectMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\020\022\016/members/_self'
  _COMMUNITY.methods_by_name['AddMember']._options = None
  _COMMUNITY.methods_by_name['AddMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\n\"\010/members'
  _COMMUNITY.methods_by_name['UpdateMember']._options = None
  _COMMUNITY.methods_by_name['UpdateMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\026\"\024/members/{member_id}'
  _COMMUNITY.methods_by_name['RemoveMember']._options = None
  _COMMUNITY.methods_by_name['RemoveMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\026*\024/members/{member_id}'
  _COMMUNITY.methods_by_name['DescribeMember']._options = None
  _COMMUNITY.methods_by_name['DescribeMember']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\026\022\024/members/{member_id}'
  _COMMUNITY.methods_by_name['ListMembers']._options = None
  _COMMUNITY.methods_by_name['ListMembers']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\n\022\010/members'
  _COMMUNITY.methods_by_name['AddMemberIdentity']._options = None
  _COMMUNITY.methods_by_name['AddMemberIdentity']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002!\"\037/members/{member_id}/identities'
  _COMMUNITY.methods_by_name['UpdateMemberIdentity']._options = None
  _COMMUNITY.methods_by_name['UpdateMemberIdentity']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002/\032-/members/{member_id}/identities/{identity_id}'
  _COMMUNITY.methods_by_name['RemoveMemberIdentity']._options = None
  _COMMUNITY.methods_by_name['RemoveMemberIdentity']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002/*-/members/{member_id}/identities/{identity_id}'
  _COMMUNITY.methods_by_name['AddAttribute']._options = None
  _COMMUNITY.methods_by_name['AddAttribute']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\r\"\013/attributes'
  _COMMUNITY.methods_by_name['UpdateAttribute']._options = None
  _COMMUNITY.methods_by_name['UpdateAttribute']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035\"\033/attributes/{attribute_key}'
  _COMMUNITY.methods_by_name['RemoveAttribute']._options = None
  _COMMUNITY.methods_by_name['RemoveAttribute']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035*\033/attributes/{attribute_key}'
  _COMMUNITY.methods_by_name['DescribeAttribute']._options = None
  _COMMUNITY.methods_by_name['DescribeAttribute']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035\022\033/attributes/{attribute_key}'
  _COMMUNITY.methods_by_name['ListAttributes']._options = None
  _COMMUNITY.methods_by_name['ListAttributes']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\r\022\013/attributes'
  _COMMUNITY.methods_by_name['DescribeIdentityProvider']._options = None
  _COMMUNITY.methods_by_name['DescribeIdentityProvider']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\006\022\004/idp'
  _COMMUNITY.methods_by_name['ConfigureIdentityProvider']._options = None
  _COMMUNITY.methods_by_name['ConfigureIdentityProvider']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\006\032\004/idp'
  _JOINSPACEINPUT._serialized_start=281
  _JOINSPACEINPUT._serialized_end=359
  _JOINSPACEOUTPUT._serialized_start=361
  _JOINSPACEOUTPUT._serialized_end=411
  _REGISTERMEMBERINPUT._serialized_start=413
  _REGISTERMEMBERINPUT._serialized_end=482
  _REGISTERMEMBEROUTPUT._serialized_start=484
  _REGISTERMEMBEROUTPUT._serialized_end=506
  _LEAVESPACEINPUT._serialized_start=508
  _LEAVESPACEINPUT._serialized_end=525
  _LEAVESPACEOUTPUT._serialized_start=527
  _LEAVESPACEOUTPUT._serialized_end=545
  _ADDMEMBERINPUT._serialized_start=547
  _ADDMEMBERINPUT._serialized_end=605
  _ADDMEMBEROUTPUT._serialized_start=607
  _ADDMEMBEROUTPUT._serialized_end=657
  _UPDATEMEMBERINPUT._serialized_start=660
  _UPDATEMEMBERINPUT._serialized_end=919
  _UPDATEMEMBERINPUT_PATCH._serialized_start=800
  _UPDATEMEMBERINPUT_PATCH._serialized_end=919
  _UPDATEMEMBEROUTPUT._serialized_start=921
  _UPDATEMEMBEROUTPUT._serialized_end=941
  _REMOVEMEMBERINPUT._serialized_start=943
  _REMOVEMEMBERINPUT._serialized_end=981
  _REMOVEMEMBEROUTPUT._serialized_start=983
  _REMOVEMEMBEROUTPUT._serialized_end=1003
  _DESCRIBEMEMBERINPUT._serialized_start=1005
  _DESCRIBEMEMBERINPUT._serialized_end=1045
  _DESCRIBEMEMBEROUTPUT._serialized_start=1047
  _DESCRIBEMEMBEROUTPUT._serialized_end=1111
  _INTROSPECTMEMBERINPUT._serialized_start=1113
  _INTROSPECTMEMBERINPUT._serialized_end=1136
  _INTROSPECTMEMBEROUTPUT._serialized_start=1138
  _INTROSPECTMEMBEROUTPUT._serialized_end=1204
  _LISTMEMBERSINPUT._serialized_start=1207
  _LISTMEMBERSINPUT._serialized_end=1703
  _LISTMEMBERSINPUT_FILTER._serialized_start=1318
  _LISTMEMBERSINPUT_FILTER._serialized_end=1703
  _LISTMEMBERSOUTPUT._serialized_start=1705
  _LISTMEMBERSOUTPUT._serialized_end=1780
  _ADDMEMBERIDENTITYINPUT._serialized_start=1782
  _ADDMEMBERIDENTITYINPUT._serialized_end=1878
  _ADDMEMBERIDENTITYOUTPUT._serialized_start=1880
  _ADDMEMBERIDENTITYOUTPUT._serialized_end=1926
  _UPDATEMEMBERIDENTITYINPUT._serialized_start=1928
  _UPDATEMEMBERIDENTITYINPUT._serialized_end=2048
  _UPDATEMEMBERIDENTITYOUTPUT._serialized_start=2050
  _UPDATEMEMBERIDENTITYOUTPUT._serialized_end=2078
  _REMOVEMEMBERIDENTITYINPUT._serialized_start=2080
  _REMOVEMEMBERIDENTITYINPUT._serialized_end=2147
  _REMOVEMEMBERIDENTITYOUTPUT._serialized_start=2149
  _REMOVEMEMBERIDENTITYOUTPUT._serialized_end=2177
  _ADDATTRIBUTEINPUT._serialized_start=2179
  _ADDATTRIBUTEINPUT._serialized_end=2269
  _ADDATTRIBUTEOUTPUT._serialized_start=2271
  _ADDATTRIBUTEOUTPUT._serialized_end=2305
  _UPDATEATTRIBUTEINPUT._serialized_start=2307
  _UPDATEATTRIBUTEINPUT._serialized_end=2400
  _UPDATEATTRIBUTEOUTPUT._serialized_start=2402
  _UPDATEATTRIBUTEOUTPUT._serialized_end=2425
  _REMOVEATTRIBUTEINPUT._serialized_start=2427
  _REMOVEATTRIBUTEINPUT._serialized_end=2472
  _REMOVEATTRIBUTEOUTPUT._serialized_start=2474
  _REMOVEATTRIBUTEOUTPUT._serialized_end=2497
  _DESCRIBEATTRIBUTEINPUT._serialized_start=2499
  _DESCRIBEATTRIBUTEINPUT._serialized_end=2546
  _DESCRIBEATTRIBUTEOUTPUT._serialized_start=2548
  _DESCRIBEATTRIBUTEOUTPUT._serialized_end=2621
  _LISTATTRIBUTESINPUT._serialized_start=2624
  _LISTATTRIBUTESINPUT._serialized_end=2990
  _LISTATTRIBUTESINPUT_FILTER._serialized_start=2741
  _LISTATTRIBUTESINPUT_FILTER._serialized_end=2990
  _LISTATTRIBUTESOUTPUT._serialized_start=2992
  _LISTATTRIBUTESOUTPUT._serialized_end=3073
  _DESCRIBEIDENTITYPROVIDERINPUT._serialized_start=3075
  _DESCRIBEIDENTITYPROVIDERINPUT._serialized_end=3106
  _DESCRIBEIDENTITYPROVIDEROUTPUT._serialized_start=3108
  _DESCRIBEIDENTITYPROVIDEROUTPUT._serialized_end=3226
  _CONFIGUREIDENTITYPROVIDERINPUT._serialized_start=3228
  _CONFIGUREIDENTITYPROVIDERINPUT._serialized_end=3346
  _CONFIGUREIDENTITYPROVIDEROUTPUT._serialized_start=3348
  _CONFIGUREIDENTITYPROVIDEROUTPUT._serialized_end=3381
  _COMMUNITY._serialized_start=3384
  _COMMUNITY._serialized_end=6671
# @@protoc_insertion_point(module_scope)
